@@ -43,11 +43,14 @@
 #define GEDIT_STDIN_BUFSIZE 1024
 
 GtkWidget *save_file_selector = NULL;
+#if 0
+/* Don't use public variables */
 GtkWidget *open_file_selector = NULL;
+#endif
 
 void file_new_cb (GtkWidget *widget, gpointer cbdata);
 void file_open_cb (GtkWidget *widget, gpointer cbdata);
-gint file_save_document (Document * doc);
+gint file_save_document (GeditDocument *doc);
 void file_save_cb (GtkWidget *widget, gpointer cbdata);
 void file_save_as_cb (GtkWidget *widget, gpointer cbdata);
 void file_save_all_cb (GtkWidget *widget, gpointer cbdata);
@@ -57,7 +60,10 @@ void file_revert_cb (GtkWidget *widget, gpointer cbdata);
 void file_quit_cb (GtkWidget *widget, gpointer cbdata);
 
        gint gedit_file_create_popup (const gchar *title);
+#if 0
+/* don't add prototypes for public functions */
 static void gedit_file_open_ok_sel   (GtkWidget *widget, GtkFileSelection *files);
+#endif
 static void gedit_file_save_as_ok_sel (GtkWidget *w, gpointer cbdata);
 static gint delete_event_cb (GtkWidget *w, GdkEventAny *e);
 static void cancel_cb (GtkWidget *w, gpointer cbdata);
@@ -71,8 +77,8 @@ gchar * gedit_file_convert_to_full_pathname (const gchar * fname);
 
 
 typedef struct {
-	Document *doc;
-	View *view;
+	GeditDocument *doc;
+	GeditView *view;
 	gchar *tmp_buf;
 } HackyStruct;
 
@@ -98,7 +104,7 @@ gedit_view_insert_if_mapped (HackyStruct *hack)
 }
 
 static void
-gedit_document_insert_text_when_mapped (Document *doc, const gchar * tmp_buf,
+gedit_document_insert_text_when_mapped (GeditDocument *doc, const gchar * tmp_buf,
 					gint pos, gboolean something)
 {
 	HackyStruct *hack;
@@ -134,18 +140,21 @@ gedit_document_insert_text_when_mapped (Document *doc, const gchar * tmp_buf,
  * Return value: 0 on success, 1 on error.
  */
 gint
-gedit_file_open (Document *doc, const gchar *fname)
+gedit_file_open (GeditDocument *doc, const gchar *fname)
 {
 	gchar *tmp_buf;
 	struct stat stats;
 	FILE *fp;
-	View *view;
+	GeditView *view;
 	
 	gint _debug;
 	
 	gedit_debug (DEBUG_FILE, "");
 
 	g_return_val_if_fail (fname != NULL, 1);
+	if (doc != NULL) {
+		g_return_val_if_fail (doc->filename != fname, -1);
+	}
 
 	if (stat(fname, &stats) ||  !S_ISREG(stats.st_mode))
 	{
@@ -156,6 +165,8 @@ gedit_file_open (Document *doc, const gchar *fname)
 		return 1;
 	}
 
+#if 0
+	/* Disable this check, the users have requested that they need to open 0  bytes files */
 	if (stats.st_size  == 0)
 	{
 		gchar *errstr = g_strdup_printf (_("An error was encountered while opening the file:\n\n%s\n\n"
@@ -165,6 +176,7 @@ gedit_file_open (Document *doc, const gchar *fname)
 		g_free (errstr);
 		return 1;
 	}
+#endif	
 
 	if ((tmp_buf = g_new0 (gchar, stats.st_size + 1)) == NULL)
 	{
@@ -190,8 +202,10 @@ gedit_file_open (Document *doc, const gchar *fname)
 		doc->untitled_number = 0;
 		gedit_document_insert_text_when_mapped (doc, tmp_buf, 0, FALSE);
 		gedit_document_set_readonly (doc, access (fname, W_OK) ? TRUE : FALSE);
+		g_free (tmp_buf);
 	} else {
-		/* Vefify that doc->filenam == NULL ??? */
+		if (doc->filename != NULL)
+			g_free (doc->filename);
 		doc->filename = g_strdup (fname);
 		doc->untitled_number = 0;
 		gedit_document_insert_text (doc, tmp_buf, 0, FALSE);
@@ -217,6 +231,17 @@ gedit_file_open (Document *doc, const gchar *fname)
 }
 
 
+static gint
+gedit_file_selector_key_event (GtkFileSelection *fsel, GdkEventKey *event)
+{
+	if (event->keyval == GDK_Escape) {
+		gtk_button_clicked (GTK_BUTTON (fsel->cancel_button));
+		return 1;
+	} else
+		return 0;
+}
+
+
 /**
  * gedit_file_save_as:
  * @doc: 
@@ -225,7 +250,7 @@ gedit_file_open (Document *doc, const gchar *fname)
  * the button
  **/
 static void
-gedit_file_save_as (Document *doc)
+gedit_file_save_as (GeditDocument *doc)
 {
 
 	gedit_debug (DEBUG_FILE, "");
@@ -251,6 +276,10 @@ gedit_file_save_as (Document *doc)
 				    "clicked",
 				    GTK_SIGNAL_FUNC(cancel_cb),
 				    save_file_selector);
+		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(save_file_selector)),
+				    "key_press_event",
+				    GTK_SIGNAL_FUNC (gedit_file_selector_key_event),
+				    NULL);
 
 		/* If this save as was the result of a close all, and the user cancels the
 		   save, clear the flag */
@@ -295,11 +324,11 @@ gedit_file_save_as (Document *doc)
  * Return value: 0 on success, 1 on error.
  */
 gint
-gedit_file_save (Document *doc, const gchar *fname)
+gedit_file_save (GeditDocument *doc, const gchar *fname)
 {
 	FILE  *file_pointer;
 	gchar *buffer;
-	View  *view;
+	GeditView  *view;
 
 	gedit_debug (DEBUG_FILE, "");
 
@@ -329,6 +358,8 @@ gedit_file_save (Document *doc, const gchar *fname)
 
 	g_return_val_if_fail (buffer != NULL, 1);
 
+#if 0
+	/* Allow the user to save 0 bytes files */
 	if (strlen(buffer) == 0)
 	{
 		gchar *errstr = g_strdup_printf (_("The document contains no data."), fname);
@@ -338,6 +369,7 @@ gedit_file_save (Document *doc, const gchar *fname)
 		gedit_close_all_flag_clear();
 		return 1;
 	}
+#endif	
 
 	if ((file_pointer = fopen (fname, "w")) == NULL)
 	{
@@ -411,13 +443,13 @@ gedit_file_save (Document *doc, const gchar *fname)
  * Return value: 0 on success, 1 on error.
  */
 gint
-gedit_file_stdin (Document *doc)
+gedit_file_stdin (GeditDocument *doc)
 {
 	gchar *tmp_buf;
 	struct stat stats;
 	guint buffer_length;
 	guint pos = 0;
-	View *view;
+	GeditView *view;
 
 	gedit_debug (DEBUG_FILE, "");
 
@@ -474,7 +506,7 @@ gedit_file_stdin (Document *doc)
 void
 file_new_cb (GtkWidget *widget, gpointer cbdata)
 {
-	Document *doc;
+	GeditDocument *doc;
 
 	gedit_debug (DEBUG_FILE, "");
 	
@@ -485,9 +517,111 @@ file_new_cb (GtkWidget *widget, gpointer cbdata)
 	doc = gedit_document_new ();
 }
 
+static GSList *
+gedit_file_selector_get_filenames (GtkFileSelection *file_selector,
+				   gchar **directory_)
+{
+	GtkCListRow *row;
+	GtkCList *rows;
+	GSList *files = NULL;
+	GList *list;
+	gchar *file;
+	gint row_num = 0;
+
+	g_return_val_if_fail (GTK_IS_FILE_SELECTION (file_selector), NULL);
+
+	rows = GTK_CLIST (file_selector->file_list);
+	list = rows->row_list;
+	for (; list != NULL; list = list->next) {
+		row = list->data;
+		gtk_clist_get_text (rows, row_num, 0, &file);
+		if (row->state == GTK_STATE_SELECTED)
+			files = g_slist_prepend (files, g_strdup(file));
+		row_num++;
+	}
+						 
+	return files;
+}
+
+static gboolean
+gedit_file_open_is_dir (GtkFileSelection *file_selector)
+{
+	static gchar *selected_file;
+	gchar *directory;
+	gint length;
+
+	selected_file = gtk_file_selection_get_filename (file_selector);
+
+	if (!g_file_test (selected_file, G_FILE_TEST_ISDIR))
+		return FALSE;
+	
+	length = strlen (selected_file);
+
+	if (selected_file [length-1] == '/')
+		directory = g_strdup (selected_file);
+	else
+		directory = g_strdup_printf ("%s%c", selected_file, '/');
+
+	gtk_file_selection_set_filename (file_selector, directory);
+	gtk_entry_set_text (GTK_ENTRY(file_selector->selection_entry), "");
+
+	g_free (directory);
+	
+	return TRUE;
+}
+
+static void
+gedit_file_open_ok_sel (GtkWidget *widget, GtkWidget *file_selector_)
+{
+	GtkFileSelection *file_selector;
+	gchar * file_name;
+	gchar * full_path;
+	gchar * directory;
+	GSList *files;
+	GSList *list;
+
+	gedit_debug (DEBUG_FILE, "");
+
+	g_return_if_fail (GTK_IS_FILE_SELECTION (file_selector_));
+	file_selector = GTK_FILE_SELECTION (file_selector_);
+
+	if (gedit_file_open_is_dir (file_selector))
+		return;
+
+	file_name = gtk_file_selection_get_filename (file_selector);
+	directory = g_dirname (file_name);
+
+	files = gedit_file_selector_get_filenames (file_selector, &directory);
+
+	if (files == NULL) {
+		if (gedit_document_new_with_file (file_name))
+			gedit_flash_va (_("Loaded file %s"), file_name);
+	} else {
+		list = files;
+		for (; list != NULL; list = list->next) {
+			file_name = list->data;
+			full_path = g_concat_dir_and_file (directory, file_name);
+			if (gedit_document_new_with_file (full_path))
+				gedit_flash_va (_("Loaded file %s"), full_path);
+			g_free (full_path);
+			g_free (file_name);
+		}
+	}
+
+	if (g_slist_length (files) > 1)
+		gedit_flash_va (_("Loaded %i files"), g_slist_length (files));
+
+	g_free (directory);
+	
+	gtk_widget_hide (GTK_WIDGET(file_selector));
+	
+	return;
+}
+
 void
 file_open_cb (GtkWidget *widget, gpointer cbdata)
 {
+	static GtkWidget *open_file_selector;
 
 	gedit_debug (DEBUG_FILE, "");
 
@@ -499,12 +633,36 @@ file_open_cb (GtkWidget *widget, gpointer cbdata)
 	if (open_file_selector == NULL)
 	{
 		open_file_selector = gtk_file_selection_new(NULL);
-		gtk_signal_connect(GTK_OBJECT(open_file_selector), "delete_event",
-				   GTK_SIGNAL_FUNC(delete_event_cb), open_file_selector);
+		gtk_signal_connect(GTK_OBJECT(open_file_selector),
+				   "delete_event",
+				   GTK_SIGNAL_FUNC (delete_event_cb),
+				   open_file_selector);
 		gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(open_file_selector)->ok_button),
-				   "clicked", GTK_SIGNAL_FUNC(gedit_file_open_ok_sel), open_file_selector);
+				   "clicked",
+				   GTK_SIGNAL_FUNC (gedit_file_open_ok_sel),
+				   open_file_selector);
 		gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(open_file_selector)->cancel_button),
-				   "clicked", GTK_SIGNAL_FUNC(cancel_cb), open_file_selector);
+				   "clicked",
+				   GTK_SIGNAL_FUNC (cancel_cb),
+				   open_file_selector);
+		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(open_file_selector)),
+				    "key_press_event",
+				    GTK_SIGNAL_FUNC (gedit_file_selector_key_event),
+				    NULL);
+		gtk_clist_set_selection_mode(
+			GTK_CLIST(GTK_FILE_SELECTION(open_file_selector)->file_list),
+			GTK_SELECTION_EXTENDED);
+	}
+	else
+	{
+		GtkFileSelection *file_selector;
+
+		g_return_if_fail (GTK_IS_FILE_SELECTION (open_file_selector));
+
+		/* Clear the selection & file from the last open */
+		file_selector = GTK_FILE_SELECTION(open_file_selector);
+		gtk_clist_unselect_all (GTK_CLIST(file_selector->file_list));
+		gtk_entry_set_text (GTK_ENTRY(file_selector->selection_entry), "");
 	}
 
 	gtk_window_set_title (GTK_WINDOW(open_file_selector), _("Open File ..."));
@@ -522,7 +680,7 @@ file_open_cb (GtkWidget *widget, gpointer cbdata)
 void
 file_save_as_cb (GtkWidget *widget, gpointer cbdata)
 {
-	Document *doc;
+	GeditDocument *doc;
 	
 	gedit_debug (DEBUG_FILE, "");
 
@@ -541,7 +699,8 @@ static gint
 delete_event_cb (GtkWidget *widget, GdkEventAny *event)
 {
 	gedit_debug (DEBUG_FILE, "");
-	
+
+	g_print ("DElete event callback ........\n");
 	gtk_widget_hide (widget);
 	return TRUE;
 }
@@ -554,27 +713,8 @@ cancel_cb (GtkWidget *w, gpointer data)
 	gtk_widget_hide (data);
 }
 
-static void
-gedit_file_open_ok_sel (GtkWidget *widget, GtkFileSelection *files)
-{
-	guchar * file_name;
-	
-	gedit_debug (DEBUG_FILE, "");
-
-	file_name = g_strdup(gtk_file_selection_get_filename (GTK_FILE_SELECTION(open_file_selector)));
-
-	if (gedit_document_new_with_file (file_name))
-	{
-		gedit_flash_va (_("Loaded file %s"), file_name);
-	}
-
-	g_free (file_name);
-	gtk_widget_hide (GTK_WIDGET(open_file_selector));
-	return;
-}
-
 gint
-file_save_document (Document * doc)
+file_save_document (GeditDocument *doc)
 {
 	gedit_debug (DEBUG_FILE, "");
 
@@ -596,7 +736,7 @@ file_save_document (Document * doc)
 void
 file_save_cb (GtkWidget *widget, gpointer cbdata)
 {
-	Document *doc;
+	GeditDocument *doc;
 	
 	gedit_debug (DEBUG_FILE, "");
 
@@ -615,13 +755,13 @@ void
 file_save_all_cb (GtkWidget *widget, gpointer cbdata)
 {
 	int i;
-	Document *doc;
+	GeditDocument *doc;
 
 	gedit_debug (DEBUG_FILE, "");
 	
         for (i = 0; i < g_list_length (mdi->children); i++)
 	{
-		doc = (Document *)g_list_nth_data (mdi->children, i);
+		doc = (GeditDocument *)g_list_nth_data (mdi->children, i);
 		gedit_file_save (doc, NULL);
 	}
 }
@@ -630,10 +770,10 @@ file_save_all_cb (GtkWidget *widget, gpointer cbdata)
 static void
 gedit_file_save_as_ok_sel (GtkWidget *w, gpointer cbdata)
 {
-	Document *doc;
+	GeditDocument *doc;
+	GeditView *nth_view;
 	gchar *file_name;
 	gint i;
-	View *nth_view;
 
 	gedit_debug (DEBUG_FILE, "");
 
@@ -784,8 +924,9 @@ void
 file_revert_cb (GtkWidget *widget, gpointer data)
 {
 	GtkWidget *msgbox;
+	GeditDocument *doc = gedit_document_current ();
 	gchar * msg;
-	Document *doc = gedit_document_current ();
+	gchar * file_name;
 
 	gedit_debug(DEBUG_FILE, "");
 
@@ -820,7 +961,9 @@ file_revert_cb (GtkWidget *widget, gpointer data)
 	{
 	case 0:
 		gedit_document_delete_text (doc, 0, gedit_document_get_buffer_length(doc), FALSE);
-		gedit_file_open (doc, doc->filename);
+		file_name = g_strdup (doc->filename);
+		gedit_file_open (doc, file_name);
+		g_free (file_name);
 		break;
 	default:
 		break;
@@ -833,7 +976,7 @@ gint
 gedit_file_create_popup (const gchar *title)
 {
 	GtkWidget *msgbox;
-	Document *doc;
+	GeditDocument *doc;
 	int ret;
 	char *msg;
 
@@ -852,7 +995,7 @@ gedit_file_create_popup (const gchar *title)
 	{
 	case 0 : 
 		doc = gedit_document_new_with_title (title);
-		doc->changed = FALSE;
+		doc->changed = TRUE;
 		return TRUE;
 	case 1 : 
 		return FALSE;
