@@ -33,6 +33,8 @@
 #include "document.h"
 #include "dialogs/dialogs.h"
 
+#define GEDIT_DISABLE_VIEW_MENU /* FIXME: This is not working correctly. Chema */
+
 GnomeUIInfo popup_menu[] =
 {
 	GNOMEUIINFO_MENU_CUT_ITEM (edit_cut_cb, NULL),
@@ -68,19 +70,13 @@ GnomeUIInfo gedit_file_menu[] =
 				GNOME_STOCK_MENU_SAVE),
 
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM (file_save_as_cb, NULL),
-#if 1
 	GNOMEUIINFO_ITEM_STOCK (N_("Revert"),
 				NULL,
 				file_revert_cb, 
 				GNOME_STOCK_MENU_REFRESH),
-#else
-	GNOMEUIINFO_ITEM_STOCK (N_("Revert"),
-				NULL,
-				file_revert_cb, 
-				GNOME_STOCK_MENU_REFRESH),
-#endif
-
-	GNOMEUIINFO_SEPARATOR, 
+	GNOMEUIINFO_SEPARATOR,
+	/* Recent files ... */
+	GNOMEUIINFO_SEPARATOR,
 
 	GNOMEUIINFO_MENU_PRINT_ITEM (file_print_cb, NULL),
 #if 0	
@@ -120,9 +116,9 @@ GnomeUIInfo gedit_edit_menu[] =
 
 	GNOMEUIINFO_SEPARATOR,
 
-	GNOMEUIINFO_MENU_FIND_ITEM ( find_cb, NULL),
-	GNOMEUIINFO_MENU_FIND_AGAIN_ITEM ( find_again_cb, NULL),
-	GNOMEUIINFO_MENU_REPLACE_ITEM ( replace_cb, NULL),
+	GNOMEUIINFO_MENU_FIND_ITEM       (gedit_find_cb, NULL),
+	GNOMEUIINFO_MENU_FIND_AGAIN_ITEM (gedit_find_again_cb, NULL),
+	GNOMEUIINFO_MENU_REPLACE_ITEM    (gedit_replace_cb, NULL),
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -130,13 +126,14 @@ GnomeUIInfo gedit_edit_menu[] =
 		GNOME_APP_UI_ITEM,
 		N_("Goto _Line..."),
 		N_("Go to a specific line number"),
-		goto_line_cb, NULL, NULL,
+		gedit_goto_line_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH
 	},
 
 	GNOMEUIINFO_END
 };
 
+#ifndef GEDIT_DISABLE_VIEW_MENU
 GnomeUIInfo view_menu[] =
 {
 	GNOMEUIINFO_ITEM_NONE (N_("_Add View"),
@@ -147,6 +144,7 @@ GnomeUIInfo view_menu[] =
 			       gedit_view_remove_cb),
 	GNOMEUIINFO_END
 };
+#endif
 
 GnomeUIInfo doc_menu[] =
 {
@@ -155,13 +153,7 @@ GnomeUIInfo doc_menu[] =
 
 GnomeUIInfo gedit_settings_menu[] =
 {
-	/* This is not working correctly . FIXME  Chema.
-	GNOMEUIINFO_TOGGLEITEM_DATA(N_("Show Statusbar"),
-				    N_("Enable or disable the statusbar at the bottom of this application window."),
-				    options_toggle_status_bar_cb,
-				    NULL, NULL),
-	*/
-	GNOMEUIINFO_MENU_PREFERENCES_ITEM (dialog_prefs, NULL),
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM (gedit_dialog_prefs, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -174,7 +166,7 @@ GnomeUIInfo gedit_docs_menu[] =
 GnomeUIInfo gedit_help_menu[] =
 {
 	GNOMEUIINFO_HELP ("gedit"),
-	GNOMEUIINFO_MENU_ABOUT_ITEM (dialog_about, NULL),
+	GNOMEUIINFO_MENU_ABOUT_ITEM (gedit_dialog_about, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -197,7 +189,9 @@ GnomeUIInfo gedit_menu[] =
 		GNOME_APP_PIXMAP_NONE, NULL,
 		0, 0, NULL
 	},
+#ifndef GEDIT_DISABLE_VIEW_MENU
 	GNOMEUIINFO_MENU_VIEW_TREE (view_menu),
+#endif	
 	GNOMEUIINFO_MENU_SETTINGS_TREE (gedit_settings_menu),
 	{
 		GNOME_APP_UI_SUBTREE,
@@ -256,11 +250,11 @@ GnomeUIInfo toolbar_data[] =
 		NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PASTE
 	},
 	{
-		GNOME_APP_UI_ITEM, N_("Find"), N_("Search for a string"), find_cb,
+		GNOME_APP_UI_ITEM, N_("Find"), N_("Search for a string"), gedit_find_cb,
 		NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SEARCH
 	},
 	{
-		GNOME_APP_UI_ITEM, N_("Line"), N_("Get file info like characters, lines, words & paragraphs count."), file_info_cb,
+		GNOME_APP_UI_ITEM, N_("Line"), N_("Get the basic file info."), gedit_file_info_cb,
 		NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_INDEX
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -271,23 +265,3 @@ GnomeUIInfo toolbar_data[] =
 	GNOMEUIINFO_END
 };
 
-
-
-#if 0
-/**
- * gedit_menus_init:
- * @window:
- * @data: 
- * 
- **/
-GnomeUIInfo *
-gedit_menus_init (Window *window)
-{
-
-	g_return_val_if_fail (window != NULL, NULL);
-
-	gnome_app_create_menus (GNOME_APP (mdi->active_window), gedit_menu);
-
-	return (GnomeUIInfo *) gedit_menu;
-}
-#endif
