@@ -22,10 +22,6 @@
  *   Chema Celorio <chema@celorio.com>
  */ 
 
-/*
-#define GEDIT_PRINT_SELECTION
-*/
-
 #include <config.h>
 #include <gnome.h>
 
@@ -53,9 +49,9 @@ typedef struct _PrintJobInfo {
 	const GnomePaper *paper;
 
 	/* document stuff */
-	Document *doc;
+	GeditDocument *doc;
 	guchar *buffer;
-	View *view;
+	GeditView *view;
 	guint buffer_size;
 	guchar *filename;
 	
@@ -96,7 +92,7 @@ typedef struct _PrintJobInfo {
 
         void file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview);
         void file_print_preview_cb (GtkWidget *widget, gpointer data);
-static  void print_document (Document *doc, PrintJobInfo *pji, GnomePrinter *printer);
+static  void print_document (GeditDocument *doc, PrintJobInfo *pji, GnomePrinter *printer);
 static  void print_line (PrintJobInfo *pji, int line);
 static  void print_ps_line(PrintJobInfo * pji, gint line, gint first_line);
 static guint print_determine_lines (PrintJobInfo *pji, int real);
@@ -109,7 +105,7 @@ static  void print_end_page (PrintJobInfo *pji);
 static  void print_end_job (GnomePrintContext *pc);
 static  void preview_destroy_cb (GtkObject *obj, PrintJobInfo *pji);
 static  void print_pji_destroy (PrintJobInfo *pji);
-static  gint print_set_pji ( PrintJobInfo * pji, Document *doc);
+static  gint print_set_pji (PrintJobInfo * pji, GeditDocument *doc);
 static  gint gedit_print_verify_fonts (void);
 
 
@@ -132,7 +128,7 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 	GtkWidget *dialog;
 	GnomePrinter *printer;
 	PrintJobInfo *pji;
-	Document * doc = gedit_document_current();
+	GeditDocument * doc = gedit_document_current();
 
 	gedit_debug (DEBUG_PRINT, "");
 	
@@ -145,8 +141,8 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 	/* Do we need to call master new with orientation ???
 	   I guess so, but it is printing fine now. Chema*/
 	pji->master = gnome_print_master_new();
-	gnome_print_master_set_paper( pji->master, pji->paper);
-	pji->pc = gnome_print_master_get_context(pji->master);
+	gnome_print_master_set_paper (pji->master, pji->paper);
+	pji->pc = gnome_print_master_get_context (pji->master);
 	g_return_if_fail(pji->pc != NULL);
 	
 	/* We need to calculate the number of pages before running
@@ -160,16 +156,13 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 	if (file_printpreview)
 	{
 		gint selection_flag;
-#ifdef GEDIT_PRINT_SELECTION		
 		guint start_pos, end_pos;
 
 		if (!gedit_view_get_selection (pji->view, &start_pos, &end_pos))
 			selection_flag = GNOME_PRINT_RANGE_SELECTION_UNSENSITIVE;
 		else
-#endif
 			selection_flag = GNOME_PRINT_RANGE_SELECTION;
 		
-
 		dialog = gnome_print_dialog_new ( (const char *)"Print Document", GNOME_PRINT_DIALOG_RANGE);
 		gnome_print_dialog_construct_range_page ( (GnomePrintDialog * )dialog,
 							  GNOME_PRINT_RANGE_ALL |
@@ -177,7 +170,6 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 							  selection_flag,
 							  1, pji->pages, "A",
 							  _("Pages")/* Translators: As in [Range] Pages from:[x]  to*/);
-
 		switch (gnome_dialog_run (GNOME_DIALOG (dialog))) {
 		case GNOME_PRINT_PRINT:
 			break;
@@ -200,7 +192,6 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 
 		pji->range = gnome_print_dialog_get_range_page ( GNOME_PRINT_DIALOG (dialog), &pji->print_first, &pji->print_last);
 
-#ifdef GEDIT_PRINT_SELECTION		
 		if (pji->range == GNOME_PRINT_RANGE_SELECTION)
 		{
 			g_free (pji->buffer);
@@ -220,7 +211,6 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 				 pji->pages);
 			*/
 		}
-#endif		
 		gnome_dialog_close (GNOME_DIALOG (dialog));
 	}
 	else
@@ -238,7 +228,10 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 
 		print_document (doc, pji, NULL);
 		title = g_strdup_printf (_("gedit (%s): Print Preview"), pji->filename);
-		preview = gnome_print_master_preview_new_with_orientation (pji->master, title, !pji->orientation);
+		preview = gnome_print_master_preview_new_with_orientation
+			(pji->master,
+			 title,
+			 !pji->orientation);
 		g_free (title);
 		gtk_signal_connect (GTK_OBJECT(preview), "destroy",
 				    GTK_SIGNAL_FUNC(preview_destroy_cb), pji);
@@ -247,11 +240,12 @@ file_print_cb (GtkWidget *widget, gpointer data, gint file_printpreview)
 	else
 	{
 		if (printer)
-			gnome_print_master_set_printer(pji->master, printer);
+			gnome_print_master_set_printer (pji->master, printer);
 		print_document (doc, pji, printer);
 		gnome_print_master_print (pji->master);
 	}
-	
+
+
 	print_pji_destroy (pji);
 	
 /*	FIXME : we need to set the parent of the dialog to be the active window,
@@ -294,7 +288,7 @@ file_print_preview_cb (GtkWidget *widget, gpointer data)
  *
  **/
 static void
-print_document (Document *doc, PrintJobInfo *pji, GnomePrinter *printer)
+print_document (GeditDocument *doc, PrintJobInfo *pji, GnomePrinter *printer)
 {
 	int current_page, current_line;
 	
@@ -351,10 +345,15 @@ print_document (Document *doc, PrintJobInfo *pji, GnomePrinter *printer)
 	}
 	print_end_job (pji->pc);
 	g_free (pji->temp);
-		
-	gnome_print_context_close (pji->pc);
+
+	
 	gnome_print_master_close (pji->master);
 
+
+	/*
+	gtk_object_unref (GTK_OBJECT (pji->pc));
+	*/
+
 }
 
 static void
@@ -490,13 +489,14 @@ print_ps_line (PrintJobInfo * pji, gint line, gint first_line)
 	gnome_print_moveto (pji->pc, pji->margin_left, y);
 	gnome_print_show (pji->pc, pji->temp);
 
+
 	if (settings->print_lines>0 && line%settings->print_lines==0 && first_line)
 	{
 		char * number_text = g_strdup_printf ("%i",line);
 		GnomeFont *temp_font = gnome_font_new (pji->font_name, 6);
 
 		g_return_if_fail (temp_font != NULL);
-		
+
 		gnome_print_setfont (pji->pc, temp_font);
 		gnome_print_moveto (pji->pc, pji->margin_left - pji->margin_numbers, y);
 		gnome_print_show   (pji->pc, number_text);
@@ -565,7 +565,7 @@ gedit_print_verify_fonts (void)
  * Return Value: TRUE on success and FALSE on error
  **/
 static gint
-print_set_pji (PrintJobInfo * pji, Document *doc)
+print_set_pji (PrintJobInfo * pji, GeditDocument *doc)
 {
 	gedit_debug (DEBUG_PRINT, "");
 
